summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/editlistviewdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/editlistviewdialog.h')
-rw-r--r--kexi/formeditor/editlistviewdialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/formeditor/editlistviewdialog.h b/kexi/formeditor/editlistviewdialog.h
index be2ae106..b6386a97 100644
--- a/kexi/formeditor/editlistviewdialog.h
+++ b/kexi/formeditor/editlistviewdialog.h
@@ -52,7 +52,7 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
TQ_OBJECT
public:
- EditListViewDialog(TQWidget *tqparent);
+ EditListViewDialog(TQWidget *parent);
~EditListViewDialog() {}
int exec(TQListView *listview);
@@ -75,9 +75,9 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
void MoveRowDown();
protected:
/*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a tqparent item.
This is used to copy the contents of a listview into another listview. */
- void loadChildNodes(TQListView *listview, TQListViewItem *item, TQListViewItem *tqparent);
+ void loadChildNodes(TQListView *listview, TQListViewItem *item, TQListViewItem *parent);
protected:
enum { BNewRow = 10, BNewChild, BRemRow, BRowUp, BRowDown , BColAdd = 20, BColRem, BColUp, BColDown };
@@ -75,9 +75,9 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
void MoveRowDown();
protected:
- /*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a tqparent item.
+ /*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a parent item.
This is used to copy the contents of a listview into another listview. */